@@ -16,13 +16,15 @@ namespace clv{
 //    all inputs as vectors
 arma::vec vec_hyp2F1(const arma::vec& vA, const arma::vec& vB, const arma::vec& vC, const arma::vec& vX);
 
-// vec_x_hyp1F1
-//    X as vector, a, b as scalars
-arma::vec vec_x_hyp1F1(double a, double b, const arma::vec& vX);
+arma::vec vec_x_kummerU(const double a, const double b, const arma::vec& vX);
 
 arma::vec vec_pow(const arma::vec& vA, const arma::vec& vP);
 
-arma::vec vec_fill(const double number, const double repetitions);
+arma::vec vec_fill(const double d, const arma::uword n);
+
+arma::vec vec_lbeta(const arma::vec& a, const double b);
+
+double lbeta(const double a, const double b);
 
 }
 
