@@ -51,6 +51,11 @@ fct.testthat.inputchecks.namescovconstr <- function(method, l.std.args){
                  regexp = "character vector")
   })
 
+  test_that("Fails if empty", {
+    expect_error(do.call(method, modifyList(l.std.args, list(names.cov.constr=character(0)))),
+                 regexp = "not be empty")
+  })
+
   test_that("Fails if any NA", {
     expect_error(do.call(method, modifyList(l.std.args, list(names.cov.constr=c(NA_character_)))),
                  regexp = "no NA")
@@ -211,20 +216,13 @@ fct.testthat.inputchecks.staticcov... <- function(method, l.std.args){
 
 fct.testthat.inputchecks.staticcov <- function(name.method, method, start.params.model, has.cor, data.apparelTrans, data.apparelStaticCov){
 
-  expect_silent(clv.data.apparel.no.holdout   <- clvdata(data.apparelTrans, date.format = "ymd", time.unit = "w"))
-  expect_silent(clv.data.apparel.with.holdout <- clvdata(data.apparelTrans, date.format = "ymd", time.unit = "w"))
-
-  expect_silent(clv.data.apparel.no.holdout <- SetStaticCovariates(clv.data = clv.data.apparel.no.holdout,
-                                                                   data.cov.life = data.apparelStaticCov, names.cov.life = "Gender",
-                                                                   data.cov.trans = data.apparelStaticCov, names.cov.trans = "Gender"))
-  expect_silent(clv.data.apparel.with.holdout <- SetStaticCovariates(clv.data = clv.data.apparel.with.holdout,
-                                                                     data.cov.life = data.apparelStaticCov, names.cov.life = "Gender",
-                                                                     data.cov.trans = data.apparelStaticCov, names.cov.trans = "Gender"))
-  l.std.args.noholdout   <- list(clv.data=clv.data.apparel.no.holdout)
+  l.std.args.noholdout   <- list(clv.data=fct.helper.create.clvdata.apparel.staticcov(estimation.split=NULL, data.apparelTrans=data.apparelTrans, data.apparelStaticCov=data.apparelStaticCov,
+                                                                                      names.cov.life="Gender", names.cov.trans="Gender"))
+  clv.data.apparel.with.holdout <- fct.helper.create.clvdata.apparel.staticcov(estimation.split=38, data.apparelTrans=data.apparelTrans, data.apparelStaticCov=data.apparelStaticCov,
+                                                                               names.cov.life="Gender", names.cov.trans="Gender")
   l.std.args.withholdout <- list(clv.data=clv.data.apparel.with.holdout)
 
 
-  context(paste0("Inputchecks - ", name.method," staticcov - Parameter start.params.model"))
   fct.testthat.inputchecks.startparamsmodel(method = method,
                                             l.std.args = l.std.args.noholdout,
                                             correct.params = start.params.model,
@@ -234,20 +232,16 @@ fct.testthat.inputchecks.staticcov <- function(name.method, method, start.params
                                             correct.params = start.params.model,
                                             names.params = names(start.params.model))
 
-  context(paste0("Inputchecks - ", name.method," staticcov - Parameter optimx.args"))
   fct.testthat.inputchecks.optimxargs(method, l.std.args.noholdout)
   fct.testthat.inputchecks.optimxargs(method, l.std.args.withholdout)
 
-  context(paste0("Inputchecks - ",name.method," staticcov - Parameter ..."))
   fct.testthat.inputchecks.staticcov...(method = method, l.std.args = l.std.args.noholdout)
   fct.testthat.inputchecks.staticcov...(method = method, l.std.args = l.std.args.withholdout)
 
   if(has.cor){
-    context(paste0("Inputchecks - ",name.method," staticcov - Parameter use.cor"))
     fct.testthat.inputchecks.usecor(method = method, l.std.args = l.std.args.noholdout)
     fct.testthat.inputchecks.usecor(method = method, l.std.args = l.std.args.withholdout)
 
-    context(paste0("Inputchecks - ",name.method," staticcov - Parameter start.param.cor"))
     fct.testthat.inputchecks.startparamcor(method = method, l.std.args = l.std.args.noholdout,   correct.param = 0.5)
     fct.testthat.inputchecks.startparamcor(method = method, l.std.args = l.std.args.withholdout, correct.param = 0.5)
   }else{
@@ -262,23 +256,18 @@ fct.testthat.inputchecks.staticcov <- function(name.method, method, start.params
 
   # Covariate specific inputs ---------------------------------------------------------------
 
-  context(paste0("Inputchecks - ",name.method," staticcov - Parameter start.param.life"))
   fct.testthat.inputchecks.startparamcov(method = method, l.std.args = l.std.args.noholdout, name.param = "start.params.life")
   fct.testthat.inputchecks.startparamcov(method = method, l.std.args = l.std.args.withholdout, name.param = "start.params.life")
 
-  context(paste0("Inputchecks - ",name.method," staticcov - Parameter start.param.trans"))
   fct.testthat.inputchecks.startparamcov(method = method, l.std.args = l.std.args.noholdout, name.param = "start.params.trans")
   fct.testthat.inputchecks.startparamcov(method = method, l.std.args = l.std.args.withholdout, name.param = "start.params.trans")
 
-  context(paste0("Inputchecks - ",name.method," staticcov - Parameter names.cov.constr"))
   fct.testthat.inputchecks.namescovconstr(method = method, l.std.args = l.std.args.noholdout)
   fct.testthat.inputchecks.namescovconstr(method = method, l.std.args = l.std.args.withholdout)
 
-  context(paste0("Inputchecks - ",name.method," staticcov - Parameter start.params.constr"))
   fct.testthat.inputchecks.startparamconstr(method = method, l.std.args = l.std.args.noholdout)
   fct.testthat.inputchecks.startparamconstr(method = method, l.std.args = l.std.args.withholdout)
 
-  context(paste0("Inputchecks - ",name.method," staticcov - Parameter reg.lambdas"))
   fct.testthat.inputchecks.reglambdas(method = method, l.std.args = l.std.args.noholdout)
   fct.testthat.inputchecks.reglambdas(method = method, l.std.args = l.std.args.withholdout)
 
