@@ -27,6 +27,47 @@ fct.testthat.inputchecks.clvfittedtransactions.plot.ellipsis <- function(l.std.a
   })
 }
 
+fct.testthat.inputchecks.clvfittedtransactions.othermodels.are.not.fitted.transaction.models <- function(clv.fitted, which){
+  test_that("other.models is not list", {
+    expect_error(plot(clv.fitted, which=which, other.models=NULL), regexp = "list of fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=123), regexp = "list of fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=clv.fitted), regexp = "list of fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=clv.fitted@clv.data), regexp = "list of fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=bgnbd), regexp = "list of fitted transaction models")
+  })
+
+  test_that("other.models contains element which are not clv.fitted.transactions", {
+    expect_error(plot(clv.fitted, which=which, other.models=list(1, 2, 3)), regexp = "fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted, NA)), regexp = "fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted, 2, clv.fitted)), regexp = "fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted@clv.data)), regexp = "fitted transaction models")
+    expect_error(plot(clv.fitted, which=which, other.models=list(pnbd, bgnbd)), regexp = "fitted transaction models")
+  })
+}
+
+
+fct.testthat.inputchecks.clvfittedtransactions.plot.label.with.othermodels <- function(clv.fitted, which, clv.fitted.other){
+
+  test_that("label has required length", {
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other), label="other"), regexp = "contain exactly")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other, clv.fitted.other), label=c("this", "other")), regexp = "contain exactly")
+  })
+
+
+  test_that("label has no empty text elements", {
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other), label=c("this", "")), regexp = "empty")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other), label=c("", "other")), regexp = "empty")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other), label=c("", "")), regexp = "empty")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other, clv.fitted.other), label=c("this", "other", "")), regexp = "empty")
+  })
+
+  test_that("label has no duplicates", {
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other), label=c("other", "other")), regexp = "duplicate")
+    expect_error(plot(clv.fitted, which=which, other.models=list(clv.fitted.other, clv.fitted.other), label=c("this", "other", "other")), regexp = "duplicate")
+  })
+
+}
+
 fct.testthat.inputchecks.clvfittedtransactions.plot.pmf.trans.bins <- function(clv.fitted){
   test_that("trans.bins is valid input (integer vector)", {
     skip_on_cran()
@@ -50,13 +91,10 @@ fct.testthat.inputchecks.clvfittedtransactions.plot.pmf <- function(data.cdnow,
                                                              data.apparelStaticCov=data.apparelStaticCov)
 
 
-  context("Inputchecks - clv.fitted.transactions plot pmf - trans.bins")
   fct.testthat.inputchecks.clvfittedtransactions.plot.pmf.trans.bins(clv.fitted = fitted.cdnow.nohold)
 
-  context("Inputchecks - clv.fitted.transactions plot pmf - calculate.remaining")
   .fct.helper.inputchecks.single.logical(fct = plot, l.std.args = l.std.args, name.param = "calculate.remaining")
 
-  context("Inputchecks - clv.fitted.transactions plot pmf - label.remaining")
   fct.helper.inputcheck.single.character(fct = plot, l.std.args = l.std.args, name.param = "label.remaining", null.allowed = FALSE)
 
 }
@@ -71,12 +109,10 @@ fct.testthat.inputchecks.clvfittedtransactions.plot.tracking <- function(data.cd
                                                              data.cdnow=data.cdnow, data.apparelTrans=data.apparelTrans,
                                                              data.apparelStaticCov=data.apparelStaticCov)
 
-  context("Inputchecks - clv.fitted.transactions plot tracking- prediction.end")
   fct.testthat.inputchecks.clvfittedtransactions.prediction.end.wrong.format(fitted.transactions = fitted.cdnow.nohold)
   fct.testthat.inputchecks.clvfittedtransactions.plot.prediction.end.before.estimation.start(fitted.transactions = fitted.cdnow.nohold)
   fct.testthat.inputchecks.clvfittedtransactions.prediction.end.uses.newdata(s3method = plot, fitted.cdnow = fitted.cdnow.nohold, data.cdnow = data.cdnow)
 
-  context("Inputchecks - clv.fitted.transactions plot tracking - cumulative")
   .fct.helper.inputchecks.single.logical(fct = plot, l.std.args = l.std.args, name.param = "cumulative")
 }
 
@@ -99,12 +135,10 @@ fct.testthat.inputchecks.clvfittedtransactions.plot.common <- function(which, l.
   fct.testthat.inputchecks.clvfittedtransactions.plot.which(clv.fitted = fitted.cdnow.nohold)
 
 
-  context(paste0("Inputchecks - clv.fitted.transactions plot ",which," - prediction params"))
   fct.testthat.inputchecks.clvfitted.na.in.prediction.params.model(s3method = plot, clv.fitted = fitted.cdnow.nohold, l.s3method.args=l.std.args)
   fct.testthat.inputchecks.clvfittedtransactions.cov.na.in.prediction.params.cov(s3method = plot, clv.fitted.cov = fitted.apparel.static,
                                                                                  l.s3method.args=l.std.args)
 
-  context(paste0("Inputchecks - clv.fitted.transactions plot ",which," - newdata"))
   fct.testthat.inputchecks.clvfitted.newdata.not.clvdata(s3method = plot, l.std.args=l.std.args, data.cdnow = data.cdnow)
   fct.testthat.inputchecks.clvfittedtransactions.newdata.has.different.covs(s3method = plot,
                                                                             l.s3method.args = l.std.args,
@@ -117,20 +151,20 @@ fct.testthat.inputchecks.clvfittedtransactions.plot.common <- function(which, l.
                                                                             clv.data.no.cov = clv.data.cdnow.nohold,
                                                                             clv.data.static.cov = clv.data.apparel.static.cov)
 
+  fct.testthat.inputchecks.clvfittedtransactions.othermodels.are.not.fitted.transaction.models(clv.fitted = fitted.cdnow.nohold, which = which)
+  fct.testthat.inputchecks.clvfittedtransactions.othermodels.are.not.fitted.transaction.models(clv.fitted = fitted.apparel.static, which = which)
 
-  context(paste0("Inputchecks - clv.fitted.transactions plot ", which," - transactions"))
-  .fct.helper.inputchecks.single.logical(fct = plot, l.std.args = l.std.args, name.param = "transactions")
-
-  context(paste0("Inputchecks - clv.fitted.transactions plot ", which," - label"))
+  # Label for single model and for when other.models is specified
   fct.helper.inputcheck.single.character(fct = plot, l.std.args = l.std.args, name.param = "label", null.allowed = TRUE)
 
-  context(paste0("Inputchecks - clv.fitted.transactions plot ", which," - plot"))
+  fct.testthat.inputchecks.clvfittedtransactions.plot.label.with.othermodels(clv.fitted=fitted.cdnow.nohold, which=which, clv.fitted.other=fitted.apparel.static)
+
+  .fct.helper.inputchecks.single.logical(fct = plot, l.std.args = l.std.args, name.param = "transactions")
+
   .fct.helper.inputchecks.single.logical(fct = plot, l.std.args = l.std.args, name.param = "plot")
 
-  context(paste0("Inputchecks - clv.fitted.transactions plot ", which," - verbose"))
   .fct.helper.inputchecks.single.logical(fct = plot, l.std.args = l.std.args, name.param = "verbose")
 
-  context(paste0("Inputchecks - clv.fitted.transactions plot ", which," - ..."))
   fct.testthat.inputchecks.clvfittedtransactions.plot.ellipsis(l.std.args = l.std.args)
 }
 
