@@ -19,7 +19,6 @@ fct.testthat.inputchecks.clvfittedspending.predict.ellipsis <- function(fitted.s
 
 
 fct.testthat.inputchecks.clvfittedspending.predict <- function(data.cdnow, data.apparelTrans, data.apparelStaticCov){
-  context("Inputchecks - clv.fitted.spending predict - newdata")
   clv.data.apparel.static.cov <- fct.helper.create.clvdata.apparel.staticcov(data.apparelTrans = data.apparelTrans, data.apparelStaticCov = data.apparelStaticCov,
                                                                              estimation.split = 40)
   expect_silent(fitted.spending <- gg(clv.data.apparel.static.cov, verbose = FALSE))
@@ -32,12 +31,10 @@ fct.testthat.inputchecks.clvfittedspending.predict <- function(data.cdnow, data.
   fct.testthat.inputchecks.clvfittedspending.predict.newdata.has.no.spending(fitted.spending = fitted.spending, data.cdnow = data.cdnow)
 
 
-  context("Inputchecks - clv.fitted.spending predict - verbose")
   l.std.args <- list(object=fitted.spending)
   .fct.helper.inputchecks.single.logical(fct = predict, l.std.args = l.std.args,
                                          name.param = "verbose", null.allowed=FALSE)
 
-  context("Inputchecks - clv.fitted.spending predict - ...")
   fct.testthat.inputchecks.clvfittedspending.predict.ellipsis(fitted.spending = fitted.spending)
 }
 
